import React, { useCallback, useMemo } from 'react';
import { View, StyleSheet, Pressable, Text } from 'react-native';
import { useCalendarContext } from '../calendar-context';
import { cn, formatNumber, getDateYear, getYearRange } from '../utils';
import { CONTAINER_HEIGHT } from '../enums';
const Years = () => {
  const {
    mode,
    numerals = 'latn',
    currentDate,
    currentYear,
    date,
    onSelectYear,
    styles = {},
    classNames = {},
    components,
    containerHeight = CONTAINER_HEIGHT
  } = useCalendarContext();
  const style = useMemo(() => createDefaultStyles(containerHeight), [containerHeight]);
  const selectedYear = getDateYear(date);
  const generateCells = useCallback(() => {
    const years = getYearRange(currentYear);
    const activeYear = getDateYear(currentDate);
    const column = years.map(year => {
      const isSelected = year === selectedYear;
      const isActivated = year === activeYear;
      const containerStyle = StyleSheet.flatten([defaultStyles.year, styles.year, isActivated && (styles === null || styles === void 0 ? void 0 : styles.active_year), mode === 'single' && isSelected && (styles === null || styles === void 0 ? void 0 : styles.selected_year)]);
      const textStyle = StyleSheet.flatten([isActivated && (styles === null || styles === void 0 ? void 0 : styles.active_year_label), mode === 'single' && isSelected && (styles === null || styles === void 0 ? void 0 : styles.selected_year_label)]);
      const containerClassName = cn(isActivated && (classNames === null || classNames === void 0 ? void 0 : classNames.active_year), mode === 'single' && isSelected ? classNames === null || classNames === void 0 ? void 0 : classNames.selected_year : classNames.year);
      const textClassName = cn(isActivated && (classNames === null || classNames === void 0 ? void 0 : classNames.active_year_label), mode === 'single' && isSelected ? classNames === null || classNames === void 0 ? void 0 : classNames.selected_year_label : classNames.year_label);
      return /*#__PURE__*/React.createElement(View, {
        key: year,
        style: style.yearCell
      }, components !== null && components !== void 0 && components.Year ? /*#__PURE__*/React.createElement(Pressable, {
        onPress: () => onSelectYear(year),
        accessibilityRole: "button",
        accessibilityLabel: year.toString(),
        style: defaultStyles.year
      }, components.Year({
        number: year,
        text: formatNumber(year, numerals),
        isSelected,
        isActivated
      })) : /*#__PURE__*/React.createElement(Pressable, {
        onPress: () => onSelectYear(year),
        accessibilityRole: "button",
        accessibilityLabel: formatNumber(year, numerals),
        style: containerStyle,
        className: containerClassName
      }, /*#__PURE__*/React.createElement(Text, {
        key: year,
        style: textStyle,
        className: textClassName
      }, formatNumber(year, numerals))));
    });
    return column;
  }, [onSelectYear, selectedYear, currentYear, currentDate, styles, mode, classNames, components === null || components === void 0 ? void 0 : components.Year]);
  return /*#__PURE__*/React.createElement(View, {
    style: [defaultStyles.container, styles.years],
    testID: "year-selector"
  }, /*#__PURE__*/React.createElement(View, {
    style: defaultStyles.years
  }, generateCells()));
};
const defaultStyles = StyleSheet.create({
  container: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center'
  },
  years: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  },
  year: {
    flex: 1,
    margin: 2,
    alignItems: 'center',
    justifyContent: 'center'
  }
});
const createDefaultStyles = containerHeight => StyleSheet.create({
  yearCell: {
    width: `${100 / 3}%`,
    height: containerHeight / 6
  }
});
export default Years;
//# sourceMappingURL=years.js.map